"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const style_1 = require("../style");
function computeTheme(customTheme) {
    const computedTheme = Object.assign({}, style_1.defaultTheme);
    if (!customTheme) {
        return computedTheme;
    }
    if (customTheme.colors) {
        computedTheme.colors = Object.assign({}, style_1.defaultTheme.colors, customTheme.colors);
    }
    if (customTheme.fontSize) {
        computedTheme.fontSize = Object.assign({}, style_1.defaultTheme.fontSize, customTheme.fontSize);
    }
    if (customTheme.borderRadius) {
        computedTheme.borderRadius = Object.assign({}, style_1.defaultTheme.borderRadius, customTheme.borderRadius);
    }
    return computedTheme;
}
exports.computeTheme = computeTheme;
exports.createSpacingStyles = (props, theme) => {
    let propKeys;
    propKeys = {
        p: "padding",
        pt: "paddingTop",
        pr: "paddingRight",
        pb: "paddingBottom",
        pl: "paddingLeft",
        px: "paddingHorizontal",
        py: "paddingVertical",
        m: "margin",
        mt: "marginTop",
        mr: "marginRight",
        mb: "marginBottom",
        ml: "marginLeft",
        mx: "marginHorizontal",
        my: "marginVertical"
    };
    let computedStyle = {};
    Object.keys(propKeys).map((propKey) => {
        const styleProperty = propKeys[propKey];
        if (propKey in props) {
            computedStyle[styleProperty] = exports.getThemeProperty(theme, props[propKey], props[propKey]);
        }
    });
    return computedStyle;
};
exports.createDirectionalStyles = (key, value, type = "string") => {
    if (typeof (value.x || value.y || value.b || value.t || value.l || value.r) ===
        "undefined") {
        return exports.createStyle(`${key}`, value, type);
    }
    let computedStyle = {};
    if (typeof value.x != "undefined") {
        computedStyle = Object.assign({}, computedStyle, exports.createStyle(`${key}Horizontal`, value.x, type));
    }
    if (typeof value.y != "undefined") {
        computedStyle = Object.assign({}, computedStyle, exports.createStyle(`${key}Vertical`, value.y, type));
    }
    if (typeof value.t != "undefined") {
        computedStyle = Object.assign({}, computedStyle, exports.createStyle(`${key}Top`, value.t, type));
    }
    if (typeof value.r != "undefined") {
        computedStyle = Object.assign({}, computedStyle, exports.createStyle(`${key}Right`, value.r, type));
    }
    if (typeof value.b != "undefined") {
        computedStyle = Object.assign({}, computedStyle, exports.createStyle(`${key}Bottom`, value.b, type));
    }
    if (typeof value.l != "undefined") {
        computedStyle = Object.assign({}, computedStyle, exports.createStyle(`${key}Left`, value.l, type));
    }
    return computedStyle;
};
exports.getThemeProperty = (theme, value, fallback) => {
    if (typeof theme[value] !== "undefined") {
        return theme[value];
    }
    return fallback;
};
exports.createBorderRadiusStyles = (props, theme) => {
    let propKeys;
    propKeys = {
        rounded: "borderRadius",
        roundedTop: ["borderTopLeftRadius", "borderTopRightRadius"],
        roundedLeft: ["borderTopLeftRadius", "borderBottomLeftRadius"],
        roundedRight: ["borderTopRightRadius", "borderBottomRightRadius"],
        roundedBottom: ["borderBottomLeftRadius", "borderBottomRightRadius"]
    };
    let computedStyle = {};
    Object.keys(propKeys).map((propKey) => {
        const styleProperty = propKeys[propKey];
        if (propKey in props) {
            if (styleProperty instanceof Array) {
                styleProperty.forEach(property => {
                    computedStyle[property] = exports.getThemeProperty(theme, props[propKey], props[propKey]);
                });
            }
            else {
                computedStyle[styleProperty] = exports.getThemeProperty(theme, props[propKey], props[propKey]);
            }
        }
    });
    return computedStyle;
};
exports.addFlexStyles = (props) => {
    let propKeys;
    propKeys = {
        flex: "flex"
    };
    let computedStyle = {};
    Object.keys(propKeys).map((propKey) => {
        const styleProperty = propKeys[propKey];
        if (propKey in props) {
            computedStyle[styleProperty] = props[propKey];
        }
    });
    return computedStyle;
};
exports.createBorderWidthStyles = (props) => {
    let propKeys;
    propKeys = {
        borderWidth: "borderWidth",
        borderTopWidth: "borderTopWidth",
        borderLeftWidth: "borderLeftWidth",
        borderRightWidth: "borderRightWidth",
        borderBottomWidth: "borderBottomWidth"
    };
    let computedStyle = {};
    Object.keys(propKeys).map((propKey) => {
        const styleProperty = propKeys[propKey];
        if (propKey in props) {
            computedStyle[styleProperty] = props[propKey];
        }
    });
    return computedStyle;
};
exports.createBorderColorStyles = (props, theme) => {
    let propKeys;
    propKeys = {
        borderColor: "borderColor",
        borderTopColor: "borderTopColor",
        borderRightColor: "borderTopColor",
        borderLeftColor: "borderLeftColor",
        borderBottomColor: "borderBottomColor"
    };
    let computedStyle = {};
    Object.keys(propKeys).map((propKey) => {
        const styleProperty = propKeys[propKey];
        if (propKey in props) {
            if (styleProperty instanceof Array) {
                styleProperty.forEach(property => {
                    computedStyle[property] = exports.getThemeProperty(theme, props[propKey], props[propKey]);
                });
            }
            else {
                computedStyle[styleProperty] = exports.getThemeProperty(theme, props[propKey], props[propKey]);
            }
        }
    });
    return computedStyle;
};
exports.createStyle = (key, value, type) => {
    return {
        [key]: type === "number" ? Number(value) : value
    };
};
exports.addPropToComputedStyle = (props, computedStyle, styleProperty, atomicProperty, type) => {
    if (props[atomicProperty]) {
        computedStyle = Object.assign({}, computedStyle, exports.createStyle(styleProperty, props[atomicProperty], type));
    }
    return computedStyle;
};
//# sourceMappingURL=theme.service.js.map