"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const react_1 = require("react");
const react_native_1 = require("react-native");
const react_native_modal_1 = __importDefault(require("react-native-modal"));
const drawer_style_1 = require("./drawer.style");
const theme_1 = require("../../theme");
const theme_service_1 = require("../../theme/theme.service");
const SCREEN_WIDTH = react_native_1.Dimensions.get("window").width;
const Drawer = React.forwardRef((props, ref) => {
    const { direction, drawerPercentage, animationTime, children } = props;
    const theme = react_1.useContext(theme_1.ThemeContext);
    const computedStyle = drawer_style_1.getStyle(theme, props);
    const [isVisible, setIsVisible] = react_1.useState(false);
    let DRAWER_WIDTH;
    if (drawerPercentage) {
        DRAWER_WIDTH = SCREEN_WIDTH * (drawerPercentage / 100);
    }
    react_1.useImperativeHandle(ref, () => ({
        open() {
            setIsVisible(true);
        },
        close() {
            setIsVisible(false);
        }
    }));
    return (<react_native_modal_1.default isVisible={isVisible} onSwipeComplete={() => setIsVisible(false)} swipeDirection={direction === "left" ? "left" : "right"} backdropColor={theme_service_1.getThemeProperty(theme.colors, props.backdropColor, "black")} backdropTransitionOutTiming={0} animationInTiming={animationTime} animationOutTiming={animationTime} animationIn={direction === "left" ? "slideInLeft" : "slideInRight"} animationOut={direction === "left" ? "slideOutLeft" : "slideOutRight"} onBackdropPress={() => setIsVisible(false)} style={computedStyle.drawer}>
      <react_native_1.SafeAreaView style={Object.assign({}, computedStyle.container, { width: DRAWER_WIDTH })}>
        {children}
      </react_native_1.SafeAreaView>
    </react_native_modal_1.default>);
});
exports.Drawer = Drawer;
Drawer.defaultProps = {
    drawerPercentage: 70,
    animationTime: 300,
    bg: "white",
    backdropColor: "black",
    direction: "left",
    rounded: "none"
};
//# sourceMappingURL=drawer.component.js.map