"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const react_1 = require("react");
const react_native_1 = require("react-native");
const snackbar_style_1 = require("./snackbar.style");
const theme_1 = require("../../theme");
const text_component_1 = require("../text/text.component");
const DURATION_MEDIUM = 7000;
const Snackbar = React.forwardRef((props, ref) => {
    const { m, mt, mr, mb, ml, p, pr, pt, pb, pl, rounded, roundedTop, roundedRight, roundedBottom, roundedLeft, children, onDismiss, duration, suffix, prefix, borderColor, borderBottomColor, borderLeftColor, borderTopColor, borderRightColor, borderWidth, borderLeftWidth, borderRightWidth, borderBottomWidth, borderTopWidth } = props, rest = __rest(props, ["m", "mt", "mr", "mb", "ml", "p", "pr", "pt", "pb", "pl", "rounded", "roundedTop", "roundedRight", "roundedBottom", "roundedLeft", "children", "onDismiss", "duration", "suffix", "prefix", "borderColor", "borderBottomColor", "borderLeftColor", "borderTopColor", "borderRightColor", "borderWidth", "borderLeftWidth", "borderRightWidth", "borderBottomWidth", "borderTopWidth"]);
    const theme = react_1.useContext(theme_1.ThemeContext);
    const computedStyle = snackbar_style_1.getStyle(theme, props);
    const [opacity] = react_1.useState(new react_native_1.Animated.Value(0.0));
    const [hidden, setHidden] = react_1.useState(true);
    let hideTimeout;
    react_1.useEffect(() => {
        return function cleanup() {
            clearTimeout(hideTimeout);
        };
    }, []);
    const hide = () => {
        if (hideTimeout) {
            clearTimeout(hideTimeout);
        }
        react_native_1.Animated.timing(opacity, {
            toValue: 0,
            duration: 100,
            useNativeDriver: true
        }).start(({ finished }) => {
            if (finished) {
                setHidden(true);
            }
        });
    };
    const show = () => {
        if (hideTimeout) {
            clearTimeout(hideTimeout);
        }
        setHidden(false);
        react_native_1.Animated.timing(opacity, {
            toValue: 1,
            duration: 200,
            useNativeDriver: true
        }).start(({ finished }) => {
            if (finished) {
                const isInfinity = duration === Number.POSITIVE_INFINITY ||
                    duration === Number.NEGATIVE_INFINITY;
                if (finished && !isInfinity) {
                    hideTimeout = setTimeout(() => {
                        hide();
                        if (onDismiss) {
                            onDismiss();
                        }
                    }, duration);
                }
            }
        });
    };
    react_1.useImperativeHandle(ref, () => ({
        show() {
            show();
        },
        hide() {
            hide();
        }
    }));
    if (hidden) {
        return null;
    }
    console.log({ computedStyle });
    return (<react_native_1.SafeAreaView pointerEvents="box-none" style={computedStyle.wrapper}>
        <react_native_1.Animated.View style={Object.assign({}, computedStyle.container, { opacity: opacity, transform: [
            {
                scale: !hidden
                    ? opacity.interpolate({
                        inputRange: [0, 1],
                        outputRange: [0.9, 1]
                    })
                    : 1
            }
        ] })} {...rest}>
          {prefix && <react_native_1.View style={computedStyle.prefix}>{prefix}</react_native_1.View>}
          <text_component_1.Text style={computedStyle.text}>{children}</text_component_1.Text>
          {suffix && <react_native_1.View style={computedStyle.suffix}>{suffix}</react_native_1.View>}
        </react_native_1.Animated.View>
      </react_native_1.SafeAreaView>);
});
exports.Snackbar = Snackbar;
Snackbar.defaultProps = {
    bg: "white",
    color: "gray900",
    p: "md",
    m: "md",
    rounded: "md",
    fontSize: "text400",
    duration: DURATION_MEDIUM,
    onDismiss: () => { },
    shadow: 2,
    shadowColor: "gray500"
};
//# sourceMappingURL=snackbar.component.js.map